@@ -19,14 +19,14 @@ public:
         m_ButtonMusicControl = new BTMusicControl();
         m_scene = new QGraphicsScene(0, 0, widgetWidth, widgetHeight - 50);
         m_scene->addItem(m_ButtonMusicControl);
-        qInfo() << "SetUp" << endl;
+        qInfo() << "SetUp" << Qt::endl;
     }
     void TearDown() //TEST跑完之后会执行TearDown
     {
         m_scene->removeItem(m_ButtonMusicControl);
         delete m_ButtonMusicControl;
         delete m_scene;
-        qInfo() << "TearDown" << endl;
+        qInfo() << "TearDown" << Qt::endl;
     }
     BTMusicControl *m_ButtonMusicControl;
     QGraphicsScene *m_scene;
